import { IModule, IModuleManager } from "../Contracts";
import { Registry } from "../Utils/Registry";
import { Channel, SagaIterator } from 'redux-saga';
/**
 * WHAT IS A PLUGIN?
 * A plugin is a contributable part of your workflow. Plugins are First Party only.
 * The plugin and the host communicate via posting messages to each other using Channels.
 * Every experience can export a PluginRegistry where the plugins can be registered.
 * The host can send messages to given plugin using the manager, and can recieve messages from plugin in a callback.
 * The Plugins get two Channels one for receiving messages and other for sending them.
 *
 * The biggest diffrentiator of a Plugin vs a module loaded in the store is the communication.
 * The plugin coomunicates with the host using Channels rather than Actions thus avoiding unnecessary reducer/selectors invocations.
 */
export declare const END_TYPE = "CHANNEL_IS_ENDED";
export interface IPluginManager<hostMessageType> {
    startInitialPlugins: () => SagaIterator;
    stopPlugin: (pluginId: string) => SagaIterator;
    startPlugin: (pluginId: string) => SagaIterator;
    isStarted: (plugInId: string) => boolean;
    dispose: () => SagaIterator;
    postMessage: (pluginId: string, message: hostMessageType) => SagaIterator;
}
/**
 * Returns the plugin manager
 * @param moduleManager Module manager to add the plugin modules so they can participate in redux flow
 * @param pluginRegistry Registry containing the plugins (host puts to hostChannel, and plugin puts to plugin channel)
 * @param initialPlugins Ids of initial plugins to load
 * @param processMessageFromPlugin This will be called when plugin sends a message to the host
 */
export declare function getPluginManager<hostMessageType, pluginMessageType>(moduleManager: IModuleManager, pluginRegistry: Registry<(takeChannel: Channel<hostMessageType>, putChannel: Channel<pluginMessageType>) => IModule<any>>, initialPlugins: string[], processMessageFromPlugin: (pluginId: string, message: pluginMessageType) => void): IPluginManager<hostMessageType>;
